@@ -1,5 +1,6 @@
 import configparser
 import os
+import warnings
 from os.path import basename, splitext
 from urllib.parse import urlparse
 
@@ -71,6 +72,8 @@ class DuckDBDataSource(DataSource):
             TextField('schema', description='Name of the schema', optional=True, default='main'),
         ]
 
+        warnings.filterwarnings('ignore', message="duckdb-engine doesn't yet support reflection on indices")
+
     def validate(self):
         return self._validate_required_fields()
 
