@@ -8,6 +8,7 @@ from rich.console import Console
 from rich.table import Table
 
 from piperider_cli.profiler import ProfileSubject
+from piperider_cli.metrics_engine import Metric
 
 console = Console()
 
@@ -104,6 +105,23 @@ def _get_state_manifest(dbt_state_dir: str):
     return manifest
 
 
+def _is_filtered_out(subject, whitelist, blacklist):
+    if whitelist is None and blacklist is None:
+        return False
+
+    if whitelist is not None:
+        upper_includes = [s.upper() for s in whitelist]
+        if subject.upper() not in upper_includes:
+            return True
+
+    if blacklist is not None:
+        upper_excludes = [s.upper() for s in blacklist]
+        if subject.upper() in upper_excludes:
+            return True
+
+    return False
+
+
 def append_descriptions(profile_result, dbt_state_dir):
     run_results = _get_state_run_results(dbt_state_dir)
     manifest = _get_state_manifest(dbt_state_dir)
@@ -130,8 +148,12 @@ def append_descriptions(profile_result, dbt_state_dir):
                 profile_result['tables'][model]['columns'][column]['description'] = f"{column_desc} - via DBT"
 
 
-def get_dbt_state_candidate(dbt_state_dir: str):
+def get_dbt_state_candidate(dbt_state_dir: str, view_profile: bool = False,
+                            whitelist: list = None, blacklist: list = None):
     candidate = []
+    material_whitelist = ['seed', 'table', 'incremental']
+    if view_profile:
+        material_whitelist.append('view')
     run_results = _get_state_run_results(dbt_state_dir)
     manifest = _get_state_manifest(dbt_state_dir)
 
@@ -143,7 +165,7 @@ def get_dbt_state_candidate(dbt_state_dir: str):
         if node.get('resource_type') not in ['model', 'seed', 'source']:
             continue
         config_material = node.get('config').get('materialized')
-        if config_material in ['seed', 'table', 'incremental']:
+        if config_material in material_whitelist and not _is_filtered_out(node.get('name'), whitelist, blacklist):
             candidate.append(ProfileSubject(node.get('alias'), node.get('schema'), node.get('name')))
 
     return candidate
@@ -201,3 +223,37 @@ def get_dbt_state_tests_result(dbt_state_dir: str):
         ))
 
     return output
+
+
+def get_dbt_state_metrics(dbt_state_dir: str):
+    manifest = _get_state_manifest(dbt_state_dir)
+
+    metrics = []
+    metric_map = {}
+    for key, metric in manifest.get('metrics').items():
+        if metric.get('calculation_method') == 'derived':
+            table = None
+            schema = None
+        else:
+            depends_on_node = metric.get('depends_on').get('nodes')[0]
+            table = manifest.get('nodes').get(depends_on_node).get('alias')
+            schema = manifest.get('nodes').get(depends_on_node).get('schema')
+
+        m = Metric(metric.get('name'), table, schema, metric.get('expression'), metric.get('timestamp'),
+                   metric.get('calculation_method'), metric.get('time_grains'), dimensions=None,
+                   filters=metric.get('filters'), label=metric.get('label'), description=metric.get('description'))
+
+        metric_map[key] = m
+        if 'piperider' in metric.get('tags'):
+            if metric.get('window'):
+                console.print(
+                    f"[[bold yellow]Warning[/bold yellow]] Skip metric '{metric.get('name')}'. Property 'window' is not supported.")
+                continue
+            metrics.append(m)
+
+    for key, metric in metric_map.items():
+        if metric.calculation_method == 'derived':
+            for depends_on_metric in manifest.get('metrics').get(key).get('depends_on').get('nodes'):
+                metric.ref_metrics.append(metric_map.get(depends_on_metric))
+
+    return metrics
