@@ -2,6 +2,7 @@ import json
 import math
 import os
 import re
+import shutil
 import sys
 import uuid
 from datetime import datetime
@@ -25,6 +26,7 @@ from piperider_cli.assertion_engine.recommender import RECOMMENDED_ASSERTION_TAG
 from piperider_cli.configuration import Configuration
 from piperider_cli.exitcode import EC_ERR_TEST_FAILED
 from piperider_cli.filesystem import FileSystem
+from piperider_cli.metrics_engine import MetricEngine, MetricEventHandler
 from piperider_cli.profiler import Profiler, ProfilerEventHandler, ProfileSubject
 
 
@@ -126,6 +128,61 @@ class RichProfilerEventHandler(ProfilerEventHandler):
         self.progress.update(task_id, advance=1)
 
 
+class RichMetricEventHandler(MetricEventHandler):
+
+    def __init__(self, metrics):
+        max_metric_width, counting_width = self._get_width(metrics)
+        total_column = TextColumn("{task.fields[coft]}", table_column=Column(width=counting_width))
+        text_column = TextColumn("{task.description}", table_column=Column(width=max_metric_width))
+        bar_column = BarColumn(bar_width=80, pulse_style=Style.from_color(Color.from_rgb(244, 164, 96)))
+        mofn_column = MofNCompleteColumn(table_column=Column(width=5, justify="right"))
+        time_elapsed_column = TimeElapsedColumn()
+
+        self.progress = Progress(total_column, text_column, bar_column, mofn_column, time_elapsed_column)
+        self.progress_started = False
+        self.tasks = {}
+        self.metric_total = 0
+        self.metric_completed = 0
+
+    @staticmethod
+    def _get_width(metrics):
+        return max([len(x) for x in metrics]), len(str(len(metrics))) * 2 + 2
+
+    def handle_run_start(self):
+        pass
+
+    def handle_run_progress(self, total: int, completed: int):
+        self.metric_total = total
+
+    def handle_run_end(self):
+        self.progress.stop()
+
+    def handle_metric_start(self, metric: str):
+        self.metric_completed += 1
+        padding = ' ' * (len(str(self.metric_total)) - len(str(self.metric_completed)))
+        coft = f'[{padding}{self.metric_completed}/{self.metric_total}]'
+        task_id = self.progress.add_task(metric, total=None, coft=coft)
+        self.tasks[metric] = task_id
+        self.progress.start()
+
+    def handle_metric_progress(self, metric: str, total: int, completed: int):
+        if completed == 0:
+            task_id = self.tasks[metric]
+            self.progress.update(task_id, total=total)
+
+    def handle_metric_end(self, metric: str):
+        self.progress.stop()
+        task_id = self.tasks[metric]
+        self.progress.remove_task(task_id)
+
+    def handle_param_query_start(self, metric: str, param: str):
+        pass
+
+    def handle_param_query_end(self, metric: str):
+        task_id = self.tasks[metric]
+        self.progress.update(task_id, advance=1)
+
+
 def _execute_assertions(console: Console, engine, ds_name: str, output, profiler_result, created_at):
     # TODO: Implement running test cases based on profiling result
     assertion_engine = AssertionEngine(engine)
@@ -573,7 +630,7 @@ class Runner():
             raise err
 
         try:
-            available_tables = ds.verify_connection()
+            available_tables = ds.verify_connection(configuration.include_views)
         except Exception as err:
             console.print(
                 f'[[bold red]FAILED[/bold red]] Failed to connect the \'{ds.name}\' data source.')
@@ -610,7 +667,8 @@ class Runner():
                     f"[bold red]Error:[/bold red] No available 'manifest.json' or 'run_results.json' under '{dbt_state_dir}'")
                 return 1
 
-            tables = dbtutil.get_dbt_state_candidate(dbt_state_dir)
+            tables = dbtutil.get_dbt_state_candidate(dbt_state_dir, configuration.include_views,
+                                                     configuration.includes, configuration.excludes)
             dbt_test_results = dbtutil.get_dbt_state_tests_result(dbt_state_dir)
 
         if table:
@@ -635,6 +693,18 @@ class Runner():
         except Exception as e:
             raise Exception(f'Profiler Exception: {type(e).__name__}(\'{e}\')')
 
+        metrics = []
+        if dbt_state_dir:
+            metrics = dbtutil.get_dbt_state_metrics(dbt_state_dir)
+
+        if metrics:
+            console.rule('Metrics')
+            run_result['metrics'] = MetricEngine(
+                engine,
+                metrics,
+                RichMetricEventHandler([m.label for m in metrics])
+            ).execute()
+
         # TODO: refactor input unused arguments
         assertion_results, assertion_exceptions = _execute_assertions(console, engine, ds.name, output,
                                                                       profiler_result, created_at)
@@ -678,6 +748,17 @@ class Runner():
         with open(output_file, 'w') as f:
             f.write(json.dumps(run_result, separators=(',', ':')))
 
+        if dbt_state_dir:
+            abs_dir = os.path.abspath(dbt_state_dir)
+            dbt_state_files = ['manifest.json', 'run_results.json', 'index.html', 'catalog.json']
+            dbt_output_dir = os.path.join(output_path, 'dbt')
+            os.makedirs(dbt_output_dir, exist_ok=True)
+            for file in dbt_state_files:
+                abs_file_path = os.path.join(abs_dir, file)
+                if not os.path.exists(abs_file_path):
+                    continue
+                shutil.copy2(abs_file_path, dbt_output_dir)
+
         if output:
             clone_directory(output_path, output)
 
